@@ -44,7 +44,7 @@ def resolve_references(line: str) -> str:
     if not references:
         raise EmptyDbtReferenceWarning("no reference has been specified")
     for reference in references:
-        stmt, match = re.subn(fr"(\s+|^){reference}\b", f"\\1{{{{ref('{reference}')}}}}", stmt)
+        stmt, match = re.subn(rf"(\s+|^){reference}\b", f"\\1{{{{ref('{reference}')}}}}", stmt)
         if not match:
             raise UnknownDbtReferenceError(f"{reference} is unknown")
     return stmt
