@@ -2,7 +2,7 @@ import json
 
 import requests
 
-from fhir_cli import FHIR_API_URL
+from fhir_cli import FHIR_API_PASSWORD, FHIR_API_URL, FHIR_API_USER
 from utils.prettify_json import prettify_json
 
 
@@ -45,6 +45,9 @@ class FhirResource:
             f"{FHIR_API_URL}/{resource_type}/$validate{f'?profile={profile}' if profile else ''}",
             data=serialized_data,
             headers={"Content-Type": "application/json+fhir"},
+            auth=(FHIR_API_USER, FHIR_API_PASSWORD)
+            if FHIR_API_USER and FHIR_API_PASSWORD
+            else None,
         )
         if r.status_code == 404:
             raise FhirValidationError(f"{resource_type} is an unknown resource type")
